@@ -197,8 +197,13 @@ read_ipums_micro_chunked <- function(
     verbose = TRUE,
     var_attrs = c("val_labels", "var_label", "var_desc"),
     lower_vars = FALSE) {
-  lower_vars_was_ignored <- check_if_lower_vars_ignored(ddi, lower_vars)
-  if (lower_vars_was_ignored) {
+  if (!inherits(ddi, "ipums_ddi") && (file_is_zip(ddi) || file_is_dir(ddi))) {
+    rlang::abort(
+      "Expected `ddi` to be an `ipums_ddi` object or the path to an .xml file."
+    )
+  }
+
+  if (check_if_lower_vars_ignored(ddi, lower_vars)) {
     rlang::warn(lower_vars_ignored_warning())
   }
 
@@ -287,8 +292,13 @@ read_ipums_micro_list_chunked <- function(
     verbose = TRUE,
     var_attrs = c("val_labels", "var_label", "var_desc"),
     lower_vars = FALSE) {
-  lower_vars_was_ignored <- check_if_lower_vars_ignored(ddi, lower_vars)
-  if (lower_vars_was_ignored) {
+  if (!inherits(ddi, "ipums_ddi") && (file_is_zip(ddi) || file_is_dir(ddi))) {
+    rlang::abort(
+      "Expected `ddi` to be an `ipums_ddi` object or the path to an .xml file."
+    )
+  }
+
+  if (check_if_lower_vars_ignored(ddi, lower_vars)) {
     rlang::warn(lower_vars_ignored_warning())
   }
   if (is.character(ddi)) ddi <- read_ipums_ddi(ddi, lower_vars = lower_vars)
